==> qtjambi-help-5.15-sources.jar: io/qt/help/QHelpSearchQueryWidget.java <==
package io.qt.help;


/**
 * <p>Simple line edit or an advanced widget to enable the user to input a search term in a standardized input mask</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html">QHelpSearchQueryWidget</a></p>
 */
public class QHelpSearchQueryWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpSearchQueryWidget.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#search">QHelpSearchQueryWidget::search()</a></p>
     */
    public final Signal0 search = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QHelpSearchQueryWidget(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpSearchQueryWidget() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#QHelpSearchQueryWidget">QHelpSearchQueryWidget::QHelpSearchQueryWidget(QWidget*)</a></p>
     */
    public QHelpSearchQueryWidget(io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QHelpSearchQueryWidget instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwidget.html#changeEvent">QWidget::changeEvent(QEvent*)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void changeEvent(io.qt.core.QEvent event) throws io.qt.QNoImplementationException {
        changeEvent_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @Deprecated
    private static void changeEvent_native_QEvent_ptr(long __this__nativeId, long event) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#collapseExtendedSearch">QHelpSearchQueryWidget::collapseExtendedSearch()</a></p>
     */
    @io.qt.QtUninvokable
    public final void collapseExtendedSearch(){
        collapseExtendedSearch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void collapseExtendedSearch_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#expandExtendedSearch">QHelpSearchQueryWidget::expandExtendedSearch()</a></p>
     */
    @io.qt.QtUninvokable
    public final void expandExtendedSearch(){
        expandExtendedSearch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void expandExtendedSearch_native(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwidget.html#focusInEvent">QWidget::focusInEvent(QFocusEvent*)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void focusInEvent(io.qt.gui.QFocusEvent focusEvent) throws io.qt.QNoImplementationException {
        focusInEvent_native_QFocusEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(focusEvent));
    }
    
    @Deprecated
    private static void focusInEvent_native_QFocusEvent_ptr(long __this__nativeId, long focusEvent) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    @io.qt.QtUninvokable
    public final boolean isCompactMode(){
        return isCompactMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCompactMode_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget-obsolete.html#query">QHelpSearchQueryWidget::query()const</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.help.QHelpSearchQuery> query(){
        return query_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.help.QHelpSearchQuery> query_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#searchInput">QHelpSearchQueryWidget::searchInput()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String searchInput(){
        return searchInput_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String searchInput_native_constfct(long __this__nativeId);
    
    public final void setCompactMode(boolean on){
        setCompactMode_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    private native void setCompactMode_native_bool(long __this__nativeId, boolean on);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget-obsolete.html#setQuery">QHelpSearchQueryWidget::setQuery(QList&lt;QHelpSearchQuery&gt;)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    public final void setQuery(java.util.Collection<io.qt.help.QHelpSearchQuery> queryList){
        setQuery_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), queryList);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void setQuery_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.help.QHelpSearchQuery> queryList);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qhelpsearchquerywidget.html#setSearchInput">QHelpSearchQueryWidget::setSearchInput(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setSearchInput(java.lang.String searchInput){
        setSearchInput_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), searchInput);
    }
    
    @io.qt.QtUninvokable
    private native void setSearchInput_native_cref_QString(long __this__nativeId, java.lang.String searchInput);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQueryWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQueryWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QHelpSearchQueryWidget instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-help-6.2.1-sources.jar: io/qt/help/QHelpSearchQueryWidget.java <==
package io.qt.help;


/**
 * <p>Simple line edit or an advanced widget to enable the user to input a search term in a standardized input mask</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html">QHelpSearchQueryWidget</a></p>
 */
public class QHelpSearchQueryWidget extends io.qt.widgets.QWidget
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QHelpSearchQueryWidget.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#search">QHelpSearchQueryWidget::search()</a></p>
     */
    public final Signal0 search = new Signal0();
    
    /**
     * <p>Overloaded constructor for {@link #QHelpSearchQueryWidget(io.qt.widgets.QWidget)}
     *  with <code>parent = null</code>.</p>
     */
    public QHelpSearchQueryWidget() {
        this((io.qt.widgets.QWidget)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#QHelpSearchQueryWidget">QHelpSearchQueryWidget::QHelpSearchQueryWidget(QWidget*)</a></p>
     */
    public QHelpSearchQueryWidget(io.qt.widgets.QWidget parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
        if (parent != null) QtJambi_LibraryUtilities.internal.setCppOwnership(this);
    }
    
    private native static void initialize_native(QHelpSearchQueryWidget instance, io.qt.widgets.QWidget parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwidget.html#changeEvent">QWidget::changeEvent(QEvent*)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void changeEvent(io.qt.core.QEvent event) throws io.qt.QNoImplementationException {
        changeEvent_native_QEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(event));
    }
    
    @Deprecated
    private static void changeEvent_native_QEvent_ptr(long __this__nativeId, long event) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#collapseExtendedSearch">QHelpSearchQueryWidget::collapseExtendedSearch()</a></p>
     */
    @io.qt.QtUninvokable
    public final void collapseExtendedSearch(){
        collapseExtendedSearch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void collapseExtendedSearch_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#expandExtendedSearch">QHelpSearchQueryWidget::expandExtendedSearch()</a></p>
     */
    @io.qt.QtUninvokable
    public final void expandExtendedSearch(){
        expandExtendedSearch_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void expandExtendedSearch_native(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qwidget.html#focusInEvent">QWidget::focusInEvent(QFocusEvent*)</a></p>
     */
    @Deprecated
    @io.qt.QtUninvokable
    protected final void focusInEvent(io.qt.gui.QFocusEvent focusEvent) throws io.qt.QNoImplementationException {
        focusInEvent_native_QFocusEvent_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(focusEvent));
    }
    
    @Deprecated
    private static void focusInEvent_native_QFocusEvent_ptr(long __this__nativeId, long focusEvent) throws io.qt.QNoImplementationException {
        throw new io.qt.QNoImplementationException();
    }
    @io.qt.QtUninvokable
    public final boolean isCompactMode(){
        return isCompactMode_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isCompactMode_native_constfct(long __this__nativeId);
    
    @Deprecated
    @io.qt.QtUninvokable
    public final io.qt.core.QList<io.qt.help.QHelpSearchQuery> query(){
        return query_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native io.qt.core.QList<io.qt.help.QHelpSearchQuery> query_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#searchInput">QHelpSearchQueryWidget::searchInput()const</a></p>
     */
    @io.qt.QtUninvokable
    public final java.lang.String searchInput(){
        return searchInput_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String searchInput_native_constfct(long __this__nativeId);
    
    public final void setCompactMode(boolean on){
        setCompactMode_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), on);
    }
    
    private native void setCompactMode_native_bool(long __this__nativeId, boolean on);
    
    @Deprecated
    @io.qt.QtUninvokable
    public final void setQuery(java.util.Collection<io.qt.help.QHelpSearchQuery> queryList){
        setQuery_native_cref_QList(QtJambi_LibraryUtilities.internal.nativeId(this), queryList);
    }
    
    @Deprecated
    @io.qt.QtUninvokable
    private native void setQuery_native_cref_QList(long __this__nativeId, java.util.Collection<io.qt.help.QHelpSearchQuery> queryList);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qhelpsearchquerywidget.html#setSearchInput">QHelpSearchQueryWidget::setSearchInput(QString)</a></p>
     */
    @io.qt.QtUninvokable
    public final void setSearchInput(java.lang.String searchInput){
        setSearchInput_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), searchInput);
    }
    
    @io.qt.QtUninvokable
    private native void setSearchInput_native_cref_QString(long __this__nativeId, java.lang.String searchInput);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQueryWidget(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QHelpSearchQueryWidget(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QHelpSearchQueryWidget instance, QDeclarativeConstructor constructor);
    
}
